
#include "string.h"
#include <stdarg.h>
#include <stdio.h>

#include "usr_system.h"
#include "usr_uart.h"

#define SPI_1 	1
#define SPI_2 	2
#define SPI_3		3

#define HW_SPI		0
#define SW_SPI		1

/* 
	Display Color: White(16 gray scale)
	Dot Matrix:16064
	Driver IC: SSD1362Z
	Interface: 4-wire SPI
*/

#if 0
#define MAX_WIDTH 160-1 //1DRAW, 2 PIXEL
#define MAX_HEIGHT 64-1
#else
#define MAX_WIDTH 160//1DRAW, 2 PIXEL
#define MAX_HEIGHT 64
#endif
#define MAX_WIDTH_SPACE 6
#define MAX_HEIGHT_SPACE 8

#if 0
#define RGB(R,G,B)                  (((R>>3)<<11) | ((G>>2)<<5) | (B>>3))

typedef enum{
    COLOR_BLACK     = RGB(  0,  0,  0), // black
    COLOR_GREY      = RGB(192,192,192), // grey
    COLOR_WHITE     = RGB(255,255,255), // white
    COLOR_RED       = RGB(255,  0,  0), // red
    COLOR_PINK      = RGB(255,192,203), // pink
    COLOR_YELLOW    = RGB(255,255,  0), // yellow
    COLOR_GOLDEN    = RGB(255,215,  0), // golden
    COLOR_BROWN     = RGB(128, 42, 42), // brown
    COLOR_BLUE      = RGB(  0,  0,255), // blue
    COLOR_CYAN      = RGB(  0,255,255), // cyan
    COLOR_GREEN     = RGB(  0,255,  0), // green
    COLOR_PURPLE    = RGB(160, 32,240), // purple
}eCOLOR;
#else
typedef enum{
    eGRAYSCALE_1      = 0x01,
    eGRAYSCALE_2        = 0x02,
    eGRAYSCALE_3        = 0x03,
    eGRAYSCALE_4        = 0x04,
    eGRAYSCALE_5        = 0x05,
    eGRAYSCALE_6        = 0x06,
    eGRAYSCALE_7        = 0x07,
    eGRAYSCALE_8        = 0x08,
    eGRAYSCALE_9        = 0x09,
    eGRAYSCALE_10        = 0x10,
    eGRAYSCALE_11        = 0x11,
    eGRAYSCALE_12       = 0x12,
    eGRAYSCALE_13       = 0x13,
    eGRAYSCALE_14      = 0x14,
    eGRAYSCALE_15       = 0x15,
}eGRAYSCALE;
#endif

typedef enum{
    eNORMALDISP      = 0x00,
    eALLONDISP        = 0x01,
    eALLOFFDISP        = 0x02,
    eINVERSEDISP        = 0x03
}eINVERTMODE;

typedef enum{
    eFADEIN      = 0x00,
    eFADEOUT        = 0x01,
}eFADEMODE;

typedef enum{
    eHORIZONTAL      = 0x00,
    eVERTICAL        = 0x01,
    eDIAGONAL        = 0x02
}eSCROLLINGDIR;

typedef enum{
    eFONT6_8      = 0x00,
    eFONT9_16        = 0x01,
}eTEXTSIZE;

typedef enum{
    eFILL      = 0x00,
    eEMPTY        = 0x01,
}eFILL_EMPTY;

typedef enum{
    eNORMAL      = 0x00,
    eRIGHT        = 0x01,
    eLEFT        = 0x02,
    eBACK        = 0x03
}eCHARDIR;

#if 0
const u8 F6x8[][6] =
{
    { 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 },   //sp0
    { 0x00, 0x00, 0x00, 0x2f, 0x00, 0x00 },   // !1
    { 0x00, 0x00, 0x07, 0x00, 0x07, 0x00 },   // "2
    { 0x00, 0x14, 0x7f, 0x14, 0x7f, 0x14 },   // #3
    { 0x00, 0x24, 0x2a, 0x7f, 0x2a, 0x12 },   // $4
    { 0x00, 0x62, 0x64, 0x08, 0x13, 0x23 },   // %5
    { 0x00, 0x36, 0x49, 0x55, 0x22, 0x50 },   // &6
    { 0x00, 0x00, 0x05, 0x03, 0x00, 0x00 },   // '7
    { 0x00, 0x00, 0x1c, 0x22, 0x41, 0x00 },   // (8
    { 0x00, 0x00, 0x41, 0x22, 0x1c, 0x00 },   // )9
    { 0x00, 0x14, 0x08, 0x3E, 0x08, 0x14 },   // *10
    { 0x00, 0x08, 0x08, 0x3E, 0x08, 0x08 },   // +11
    { 0x00, 0x00, 0x00, 0xA0, 0x60, 0x00 },   // ,12
    { 0x00, 0x08, 0x08, 0x08, 0x08, 0x08 },   // -13
    { 0x00, 0x00, 0x60, 0x60, 0x00, 0x00 },   // .14
    { 0x00, 0x20, 0x10, 0x08, 0x04, 0x02 },   // /15
    { 0x00, 0x3E, 0x51, 0x49, 0x45, 0x3E },   // 016
    { 0x00, 0x00, 0x42, 0x7F, 0x40, 0x00 },   // 117
    { 0x00, 0x42, 0x61, 0x51, 0x49, 0x46 },   // 218
    { 0x00, 0x21, 0x41, 0x45, 0x4B, 0x31 },   // 319
    { 0x00, 0x18, 0x14, 0x12, 0x7F, 0x10 },   // 420
    { 0x00, 0x27, 0x45, 0x45, 0x45, 0x39 },   // 521
    { 0x00, 0x3C, 0x4A, 0x49, 0x49, 0x30 },   // 622
    { 0x00, 0x01, 0x71, 0x09, 0x05, 0x03 },   // 723
    { 0x00, 0x36, 0x49, 0x49, 0x49, 0x36 },   // 824
    { 0x00, 0x06, 0x49, 0x49, 0x29, 0x1E },   // 925
    { 0x00, 0x00, 0x36, 0x36, 0x00, 0x00 },   // :26
    { 0x00, 0x00, 0x56, 0x36, 0x00, 0x00 },   // ;27
    { 0x00, 0x08, 0x14, 0x22, 0x41, 0x00 },   // <28
    { 0x00, 0x14, 0x14, 0x14, 0x14, 0x14 },   // =29
    { 0x00, 0x00, 0x41, 0x22, 0x14, 0x08 },   // >30
    { 0x00, 0x02, 0x01, 0x51, 0x09, 0x06 },   // ?31
    { 0x00, 0x32, 0x49, 0x59, 0x51, 0x3E },   // @32
    { 0x00, 0x7C, 0x12, 0x11, 0x12, 0x7C },   // A33
    { 0x00, 0x7F, 0x49, 0x49, 0x49, 0x36 },   // B34
    { 0x00, 0x3E, 0x41, 0x41, 0x41, 0x22 },   // C35
    { 0x00, 0x7F, 0x41, 0x41, 0x22, 0x1C },   // D36
    { 0x00, 0x7F, 0x49, 0x49, 0x49, 0x41 },   // E37
    { 0x00, 0x7F, 0x09, 0x09, 0x09, 0x01 },   // F38
    { 0x00, 0x3E, 0x41, 0x49, 0x49, 0x7A },   // G39
    { 0x00, 0x7F, 0x08, 0x08, 0x08, 0x7F },   // H40
    { 0x00, 0x00, 0x41, 0x7F, 0x41, 0x00 },   // I41
    { 0x00, 0x20, 0x40, 0x41, 0x3F, 0x01 },   // J42
    { 0x00, 0x7F, 0x08, 0x14, 0x22, 0x41 },   // K43
    { 0x00, 0x7F, 0x40, 0x40, 0x40, 0x40 },   // L44
    { 0x00, 0x7F, 0x02, 0x0C, 0x02, 0x7F },   // M45
    { 0x00, 0x7F, 0x04, 0x08, 0x10, 0x7F },   // N46
    { 0x00, 0x3E, 0x41, 0x41, 0x41, 0x3E },   // O47
    { 0x00, 0x7F, 0x09, 0x09, 0x09, 0x06 },   // P48
    { 0x00, 0x3E, 0x41, 0x51, 0x21, 0x5E },   // Q49
    { 0x00, 0x7F, 0x09, 0x19, 0x29, 0x46 },   // R50
    { 0x00, 0x46, 0x49, 0x49, 0x49, 0x31 },   // S51
    { 0x00, 0x01, 0x01, 0x7F, 0x01, 0x01 },   // T52
    { 0x00, 0x3F, 0x40, 0x40, 0x40, 0x3F },   // U53
    { 0x00, 0x1F, 0x20, 0x40, 0x20, 0x1F },   // V54
    { 0x00, 0x3F, 0x40, 0x38, 0x40, 0x3F },   // W55
    { 0x00, 0x63, 0x14, 0x08, 0x14, 0x63 },   // X56
    { 0x00, 0x07, 0x08, 0x70, 0x08, 0x07 },   // Y57
    { 0x00, 0x61, 0x51, 0x49, 0x45, 0x43 },   // Z58
    { 0x00, 0x00, 0x7F, 0x41, 0x41, 0x00 },   // [59
    { 0x00, 0x02, 0x04, 0x08, 0x10, 0x20 },   // \60
    { 0x00, 0x00, 0x41, 0x41, 0x7F, 0x00 },   // ]61
    { 0x00, 0x04, 0x02, 0x01, 0x02, 0x04 },   // ^62
    { 0x00, 0x40, 0x40, 0x40, 0x40, 0x40 },   // _63
    { 0x00, 0x00, 0x01, 0x02, 0x04, 0x00 },   // '64
    { 0x00, 0x20, 0x54, 0x54, 0x54, 0x78 },   // a65
    { 0x00, 0x7F, 0x48, 0x44, 0x44, 0x38 },   // b66
    { 0x00, 0x38, 0x44, 0x44, 0x44, 0x20 },   // c67
    { 0x00, 0x38, 0x44, 0x44, 0x48, 0x7F },   // d68
    { 0x00, 0x38, 0x54, 0x54, 0x54, 0x18 },   // e69
    { 0x00, 0x08, 0x7E, 0x09, 0x01, 0x02 },   // f70
    { 0x00, 0x18, 0xA4, 0xA4, 0xA4, 0x7C },   // g71
    { 0x00, 0x7F, 0x08, 0x04, 0x04, 0x78 },   // h72
    { 0x00, 0x00, 0x44, 0x7D, 0x40, 0x00 },   // i73
    { 0x00, 0x40, 0x80, 0x84, 0x7D, 0x00 },   // j74
    { 0x00, 0x7F, 0x10, 0x28, 0x44, 0x00 },   // k75
    { 0x00, 0x00, 0x41, 0x7F, 0x40, 0x00 },   // l76
    { 0x00, 0x7C, 0x04, 0x18, 0x04, 0x78 },   // m77
    { 0x00, 0x7C, 0x08, 0x04, 0x04, 0x78 },   // n78
    { 0x00, 0x38, 0x44, 0x44, 0x44, 0x38 },   // o79
    { 0x00, 0xFC, 0x24, 0x24, 0x24, 0x18 },   // p80
    { 0x00, 0x18, 0x24, 0x24, 0x18, 0xFC },   // q81
    { 0x00, 0x7C, 0x08, 0x04, 0x04, 0x08 },   // r82
    { 0x00, 0x48, 0x54, 0x54, 0x54, 0x20 },   // s83
    { 0x00, 0x04, 0x3F, 0x44, 0x40, 0x20 },   // t84
    { 0x00, 0x3C, 0x40, 0x40, 0x20, 0x7C },   // u85
    { 0x00, 0x1C, 0x20, 0x40, 0x20, 0x1C },   // v86
    { 0x00, 0x3C, 0x40, 0x30, 0x40, 0x3C },   // w87
    { 0x00, 0x44, 0x28, 0x10, 0x28, 0x44 },   // x88
    { 0x00, 0x1C, 0xA0, 0xA0, 0xA0, 0x7C },   // y89
    { 0x00, 0x44, 0x64, 0x54, 0x4C, 0x44 },   // z90
    { 0x14, 0x14, 0x14, 0x14, 0x14, 0x14 }    // horiz lines91
};
#else
const u8 F6x8[][6] =
{
{0x00,0x00,0x00,0x00,0x00,0x00},	//	space	0x20
{0x00,0x00,0x5F,0x00,0x00,0x00},	//	!
{0x00,0x00,0x03,0x00,0x00,0x00},	//	"
{0x00,0x14,0x7F,0x14,0x7F,0x14},	//	#
{0x00,0x24,0x2A,0x7F,0x2A,0x12},	//	$
{0x00,0x23,0x13,0x08,0x64,0x62},	//	%
{0x00,0x36,0x49,0x56,0x20,0x20},	//	&
{0x00,0x00,0x0B,0x07,0x00,0x00},	//	'
{0x00,0x00,0x00,0x3E,0x41,0x00},	//	(
{0x00,0x00,0x41,0x3E,0x00,0x00},	//	)
{0x00,0x08,0x2A,0x1C,0x2A,0x08},	//	*
{0x00,0x08,0x08,0x3E,0x08,0x08},	//	+
{0x00,0x00,0x58,0x38,0x00,0x00},	//	,
{0x00,0x08,0x08,0x08,0x08,0x08},	//	-
{0x00,0x00,0x30,0x30,0x00,0x00},	//	.
{0x00,0x20,0x10,0x08,0x04,0x02},	//	/
{0x00,0x3E,0x51,0x49,0x45,0x3E},	//	0		
{0x00,0x00,0x42,0x7F,0x40,0x00},	//	1
{0x00,0x62,0x51,0x49,0x49,0x46},	//	2
{0x00,0x22,0x41,0x49,0x49,0x36},	//	3
{0x00,0x18,0x14,0x12,0x7F,0x10},	//	4
{0x00,0x27,0x45,0x45,0x45,0x39},	//	5
{0x00,0x3C,0x4A,0x49,0x49,0x30},	//	6
{0x00,0x01,0x71,0x09,0x05,0x03},	//	7
{0x00,0x36,0x49,0x49,0x49,0x36},	//	8
{0x00,0x06,0x49,0x49,0x29,0x1E},	//	9
{0x00,0x00,0x36,0x36,0x00,0x00},	//	:
{0x00,0x00,0x5B,0x3B,0x00,0x00},	//	;
{0x00,0x00,0x08,0x14,0x22,0x41},	//	<
{0x00,0x14,0x14,0x14,0x14,0x14},	//	=
{0x00,0x41,0x22,0x14,0x08,0x00},	//	>
{0x00,0x02,0x01,0x51,0x09,0x06},	//	?
{0x00,0x3E,0x41,0x5D,0x55,0x1E},	//	@
{0x00,0x7E,0x09,0x09,0x09,0x7E},	//	A		
{0x00,0x7E,0x49,0x49,0x49,0x36},	//	B
{0x00,0x3E,0x41,0x41,0x41,0x22},	//	C
{0x00,0x7F,0x41,0x41,0x41,0x3E},	//	D
{0x00,0x7F,0x49,0x49,0x49,0x41},	//	E
{0x00,0x7F,0x09,0x09,0x09,0x01},	//	F
{0x00,0x3E,0x41,0x41,0x51,0x32},	//	G
{0x00,0x7F,0x08,0x08,0x08,0x7F},	//	H
{0x00,0x00,0x41,0x7f,0x41,0x00},	//	I
{0x00,0x20,0x40,0x40,0x40,0x3F},	//	J
{0x00,0x7F,0x08,0x14,0x22,0x41},	//	K
{0x00,0x7F,0x40,0x40,0x40,0x40},	//	L
{0x00,0x7F,0x02,0x0C,0x02,0x7F},	//	M
{0x00,0x7F,0x04,0x08,0x10,0x7F},	//	N
{0x00,0x3E,0x41,0x41,0x41,0x3E},	//	O
{0x00,0x7F,0x09,0x09,0x09,0x06},	//	P
{0x00,0x3E,0x41,0x51,0x21,0x5E},	//	Q
{0x00,0x7F,0x09,0x19,0x29,0x46},	//	R
{0x00,0x26,0x49,0x49,0x49,0x32},	//	S
{0x00,0x01,0x01,0x7F,0x01,0x01},	//	T
{0x00,0x3F,0x40,0x40,0x40,0x3F},	//	U
{0x00,0x07,0x18,0x60,0x18,0x07},	//	V
{0x00,0x7F,0x20,0x18,0x20,0x7F},	//	W
{0x00,0x63,0x14,0x08,0x14,0x63},	//	X
{0x00,0x03,0x04,0x78,0x04,0x03},	//	Y
{0x00,0x61,0x51,0x49,0x45,0x43},	//	Z
{0x00,0x00,0x7F,0x41,0x41,0x00},//[59
{0x00,0x02,0x04,0x08,0x10,0x20},//\60
{0x00,0x00,0x41,0x41,0x7F,0x00},//]61
{0x00,0x04,0x02,0x01,0x02,0x04},//^62
{0x00,0x40,0x40,0x40,0x40,0x40},//_63
{0x00,0x00,0x01,0x02,0x04,0x00},//'64
{0x00,0x20,0x54,0x54,0x54,0x78},//a65
{0x00,0x7F,0x48,0x44,0x44,0x38},//b66
{0x00,0x38,0x44,0x44,0x44,0x20},//c67
{0x00,0x38,0x44,0x44,0x48,0x7F},//d68
{0x00,0x38,0x54,0x54,0x54,0x18},//e69
{0x00,0x08,0x7E,0x09,0x01,0x02},//f70
{0x00,0x18,0xA4,0xA4,0xA4,0x7C},//g71
{0x00,0x7F,0x08,0x04,0x04,0x78},//h72
{0x00,0x00,0x44,0x7D,0x40,0x00},//i73
{0x00,0x40,0x80,0x84,0x7D,0x00},//j74
{0x00,0x7F,0x10,0x28,0x44,0x00},//k75
{0x00,0x00,0x41,0x7F,0x40,0x00},//l76
{0x00,0x7C,0x04,0x18,0x04,0x78},//m77
{0x00,0x7C,0x08,0x04,0x04,0x78},//n78
{0x00,0x38,0x44,0x44,0x44,0x38},//o79
{0x00,0xFC,0x24,0x24,0x24,0x18},//p80
{0x00,0x18,0x24,0x24,0x18,0xFC},//q81
{0x00,0x7C,0x08,0x04,0x04,0x08},//r82
{0x00,0x48,0x54,0x54,0x54,0x20},//s83
{0x00,0x04,0x3F,0x44,0x40,0x20},//t84
{0x00,0x3C,0x40,0x40,0x20,0x7C},//u85
{0x00,0x1C,0x20,0x40,0x20,0x1C},//v86
{0x00,0x3C,0x40,0x30,0x40,0x3C},//w87
{0x00,0x44,0x28,0x10,0x28,0x44},//x88
{0x00,0x1C,0xA0,0xA0,0xA0,0x7C},//y89
{0x00,0x44,0x64,0x54,0x4C,0x44},//z90
{0x14,0x14,0x14,0x14,0x14,0x14}//horizlines91
	};
#endif

const u16 F9x16[][16] = {
    /*
     * code=0, hex=0x00, ascii="^@"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=1, hex=0x01, ascii="^A"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7E00,  /* 011111100 */
    0x8100,  /* 100000010 */
    0xA500,  /* 101001010 */
    0x8100,  /* 100000010 */
    0x8100,  /* 100000010 */
    0xBD00,  /* 101111010 */
    0x9900,  /* 100110010 */
    0x8100,  /* 100000010 */
    0x7E00,  /* 011111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=2, hex=0x02, ascii="^B"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7E00,  /* 011111100 */
    0xFF00,  /* 111111110 */
    0xDB00,  /* 110110110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0xFF00,  /* 111111110 */
    0x7E00,  /* 011111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=3, hex=0x03, ascii="^C"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3600,  /* 001101100 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x1C00,  /* 000111000 */
    0x0800,  /* 000010000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=4, hex=0x04, ascii="^D"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0800,  /* 000010000 */
    0x1C00,  /* 000111000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x1C00,  /* 000111000 */
    0x0800,  /* 000010000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=5, hex=0x05, ascii="^E"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0xE700,  /* 111001110 */
    0xE700,  /* 111001110 */
    0xE700,  /* 111001110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=6, hex=0x06, ascii="^F"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x7E00,  /* 011111100 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=7, hex=0x07, ascii="^G"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=8, hex=0x08, ascii="^H"
     */
    {0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00},  /* 111111110 */

    /*
     * code=9, hex=0x09, ascii="^I"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x4200,  /* 010000100 */
    0x4200,  /* 010000100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=10, hex=0x0A, ascii="^J"
     */
    {0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC300,  /* 110000110 */
    0x9900,  /* 100110010 */
    0xBD00,  /* 101111010 */
    0xBD00,  /* 101111010 */
    0x9900,  /* 100110010 */
    0xC300,  /* 110000110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xFF00},  /* 111111110 */

    /*
     * code=11, hex=0x0B, ascii="^K"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0F00,  /* 000011110 */
    0x0700,  /* 000001110 */
    0x0D00,  /* 000011010 */
    0x1900,  /* 000110010 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=12, hex=0x0C, ascii="^L"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=13, hex=0x0D, ascii="^M"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3F00,  /* 001111110 */
    0x3300,  /* 001100110 */
    0x3F00,  /* 001111110 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x7000,  /* 011100000 */
    0xF000,  /* 111100000 */
    0xE000,  /* 111000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=14, hex=0x0E, ascii="^N"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6700,  /* 011001110 */
    0xE700,  /* 111001110 */
    0xE600,  /* 111001100 */
    0xC000,  /* 110000000 */
    0x0000},  /* 000000000 */

    /*
     * code=15, hex=0x0F, ascii="^O"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xDB00,  /* 110110110 */
    0x3C00,  /* 001111000 */
    0xE700,  /* 111001110 */
    0x3C00,  /* 001111000 */
    0xDB00,  /* 110110110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=16, hex=0x10, ascii="^P"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x4000,  /* 010000000 */
    0x6000,  /* 011000000 */
    0x7000,  /* 011100000 */
    0x7800,  /* 011110000 */
    0x7C00,  /* 011111000 */
    0x7E00,  /* 011111100 */
    0x7C00,  /* 011111000 */
    0x7800,  /* 011110000 */
    0x7000,  /* 011100000 */
    0x6000,  /* 011000000 */
    0x4000,  /* 010000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=17, hex=0x11, ascii="^Q"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0100,  /* 000000010 */
    0x0300,  /* 000000110 */
    0x0700,  /* 000001110 */
    0x0F00,  /* 000011110 */
    0x1F00,  /* 000111110 */
    0x3F00,  /* 001111110 */
    0x1F00,  /* 000111110 */
    0x0F00,  /* 000011110 */
    0x0700,  /* 000001110 */
    0x0300,  /* 000000110 */
    0x0100,  /* 000000010 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=18, hex=0x12, ascii="^R"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=19, hex=0x13, ascii="^S"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=20, hex=0x14, ascii="^T"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0x7B00,  /* 011110110 */
    0x1B00,  /* 000110110 */
    0x1B00,  /* 000110110 */
    0x1B00,  /* 000110110 */
    0x1B00,  /* 000110110 */
    0x1B00,  /* 000110110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=21, hex=0x15, ascii="^U"
     */
    {0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x3000,  /* 001100000 */
    0x1C00,  /* 000111000 */
    0x3600,  /* 001101100 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x3600,  /* 001101100 */
    0x1C00,  /* 000111000 */
    0x0600,  /* 000001100 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x3E00,  /* 001111100 */
    0x0000},  /* 000000000 */

    /*
     * code=22, hex=0x16, ascii="^V"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=23, hex=0x17, ascii="^W"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0x0000},  /* 000000000 */

    /*
     * code=24, hex=0x18, ascii="^X"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=25, hex=0x19, ascii="^Y"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=26, hex=0x1A, ascii="^Z"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1C00,  /* 000111000 */
    0x0E00,  /* 000011100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=27, hex=0x1B, ascii="^["
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3800,  /* 001110000 */
    0x7000,  /* 011100000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x7000,  /* 011100000 */
    0x3800,  /* 001110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=28, hex=0x1C, ascii="^\"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=29, hex=0x1D, ascii="^]"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x2400,  /* 001001000 */
    0x6600,  /* 011001100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x6600,  /* 011001100 */
    0x2400,  /* 001001000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=30, hex=0x1E, ascii="^^"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0x7E00,  /* 011111100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=31, hex=0x1F, ascii="^_"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x7E00,  /* 011111100 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=32, hex=0x20, ascii=" "
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=33, hex=0x21, ascii="!"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=34, hex=0x22, ascii="""
     */
    {0x0000,  /* 000000000 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x2200,  /* 001000100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=35, hex=0x23, ascii="#"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=36, hex=0x24, ascii="$"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0xFF00,  /* 111111110 */
    0xC300,  /* 110000110 */
    0xE000,  /* 111000000 */
    0x7000,  /* 011100000 */
    0x3C00,  /* 001111000 */
    0x1E00,  /* 000111100 */
    0x0700,  /* 000001110 */
    0xC300,  /* 110000110 */
    0xFF00,  /* 111111110 */
    0x7E00,  /* 011111100 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000},  /* 000000000 */

    /*
     * code=37, hex=0x25, ascii="%"
     */
    {0x0000,  /* 000000000 */
    0x7000,  /* 011100000 */
    0xD800,  /* 110110000 */
    0xD900,  /* 110110010 */
    0x7300,  /* 011100110 */
    0x0600,  /* 000001100 */
    0x0C00,  /* 000011000 */
    0x1800,  /* 000110000 */
    0x3000,  /* 001100000 */
    0x6000,  /* 011000000 */
    0xCE00,  /* 110011100 */
    0x9B00,  /* 100110110 */
    0x1B00,  /* 000110110 */
    0x0E00,  /* 000011100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=38, hex=0x26, ascii="&"
     */
    {0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x7800,  /* 011110000 */
    0xCC00,  /* 110011000 */
    0xC500,  /* 110001010 */
    0xC700,  /* 110001110 */
    0xC600,  /* 110001100 */
    0xEC00,  /* 111011000 */
    0x7F00,  /* 011111110 */
    0x3B00,  /* 001110110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=39, hex=0x27, ascii="'"
     */
    {0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3000,  /* 001100000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=40, hex=0x28, ascii="("
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0C00,  /* 000011000 */
    0x1800,  /* 000110000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x1800,  /* 000110000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=41, hex=0x29, ascii=")"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x0C00,  /* 000011000 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0C00,  /* 000011000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=42, hex=0x2A, ascii="*"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x4200,  /* 010000100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0xFF00,  /* 111111110 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x4200,  /* 010000100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=43, hex=0x2B, ascii="+"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=44, hex=0x2C, ascii=","
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3000,  /* 001100000 */
    0x0000},  /* 000000000 */

    /*
     * code=45, hex=0x2D, ascii="-"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=46, hex=0x2E, ascii="."
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=47, hex=0x2F, ascii="/"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0100,  /* 000000010 */
    0x0300,  /* 000000110 */
    0x0700,  /* 000001110 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x7000,  /* 011100000 */
    0xE000,  /* 111000000 */
    0xC000,  /* 110000000 */
    0x8000,  /* 100000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=48, hex=0x30, ascii="0"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC700,  /* 110001110 */
    0xCB00,  /* 110010110 */
    0xD300,  /* 110100110 */
    0xE300,  /* 111000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=49, hex=0x31, ascii="1"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3800,  /* 001110000 */
    0x7800,  /* 011110000 */
    0x7800,  /* 011110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0x7E00,  /* 011111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=50, hex=0x32, ascii="2"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0x0300,  /* 000000110 */
    0x0700,  /* 000001110 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x7000,  /* 011100000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=51, hex=0x33, ascii="3"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0x0300,  /* 000000110 */
    0x0700,  /* 000001110 */
    0x3E00,  /* 001111100 */
    0x3E00,  /* 001111100 */
    0x0700,  /* 000001110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=52, hex=0x34, ascii="4"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0600,  /* 000001100 */
    0x0E00,  /* 000011100 */
    0x1E00,  /* 000111100 */
    0x3600,  /* 001101100 */
    0x6600,  /* 011001100 */
    0xC600,  /* 110001100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=53, hex=0x35, ascii="5"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xFC00,  /* 111111000 */
    0xFE00,  /* 111111100 */
    0x0700,  /* 000001110 */
    0x0300,  /* 000000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=54, hex=0x36, ascii="6"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1F00,  /* 000111110 */
    0x3F00,  /* 001111110 */
    0x7000,  /* 011100000 */
    0xE000,  /* 111000000 */
    0xFC00,  /* 111111000 */
    0xFE00,  /* 111111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=55, hex=0x37, ascii="7"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0300,  /* 000000110 */
    0x0700,  /* 000001110 */
    0x0600,  /* 000001100 */
    0x0E00,  /* 000011100 */
    0x0C00,  /* 000011000 */
    0x1C00,  /* 000111000 */
    0x1800,  /* 000110000 */
    0x3800,  /* 001110000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=56, hex=0x38, ascii="8"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=57, hex=0x39, ascii="9"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xE300,  /* 111000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0xC700,  /* 110001110 */
    0xFE00,  /* 111111100 */
    0x7C00,  /* 011111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=58, hex=0x3A, ascii=":"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=59, hex=0x3B, ascii=";"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3000,  /* 001100000 */
    0x0000},  /* 000000000 */

    /*
     * code=60, hex=0x3C, ascii="<"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0700,  /* 000001110 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x7000,  /* 011100000 */
    0xE000,  /* 111000000 */
    0x7000,  /* 011100000 */
    0x3800,  /* 001110000 */
    0x1C00,  /* 000111000 */
    0x0E00,  /* 000011100 */
    0x0700,  /* 000001110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=61, hex=0x3D, ascii="="
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=62, hex=0x3E, ascii=">"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xE000,  /* 111000000 */
    0x7000,  /* 011100000 */
    0x3800,  /* 001110000 */
    0x1C00,  /* 000111000 */
    0x0E00,  /* 000011100 */
    0x0700,  /* 000001110 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x7000,  /* 011100000 */
    0xE000,  /* 111000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=63, hex=0x3F, ascii="?"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0x0300,  /* 000000110 */
    0x0700,  /* 000001110 */
    0x0E00,  /* 000011100 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=64, hex=0x40, ascii="@"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xCF00,  /* 110011110 */
    0xD900,  /* 110110010 */
    0xD100,  /* 110100010 */
    0xD300,  /* 110100110 */
    0xDE00,  /* 110111100 */
    0xC000,  /* 110000000 */
    0xE300,  /* 111000110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=65, hex=0x41, ascii="A"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=66, hex=0x42, ascii="B"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFC00,  /* 111111000 */
    0xFE00,  /* 111111100 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xFE00,  /* 111111100 */
    0xFE00,  /* 111111100 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xFE00,  /* 111111100 */
    0xFC00,  /* 111111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=67, hex=0x43, ascii="C"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=68, hex=0x44, ascii="D"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFC00,  /* 111111000 */
    0xFE00,  /* 111111100 */
    0xC700,  /* 110001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC700,  /* 110001110 */
    0xFE00,  /* 111111100 */
    0xFC00,  /* 111111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=69, hex=0x45, ascii="E"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xFE00,  /* 111111100 */
    0xFE00,  /* 111111100 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=70, hex=0x46, ascii="F"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xFE00,  /* 111111100 */
    0xFE00,  /* 111111100 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=71, hex=0x47, ascii="G"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0xE300,  /* 111000110 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xCF00,  /* 110011110 */
    0xCF00,  /* 110011110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=72, hex=0x48, ascii="H"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=73, hex=0x49, ascii="I"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7E00,  /* 011111100 */
    0x7E00,  /* 011111100 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0x7E00,  /* 011111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=74, hex=0x4A, ascii="J"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=75, hex=0x4B, ascii="K"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC600,  /* 110001100 */
    0xCE00,  /* 110011100 */
    0xDC00,  /* 110111000 */
    0xF800,  /* 111110000 */
    0xF000,  /* 111100000 */
    0xE000,  /* 111000000 */
    0xF000,  /* 111100000 */
    0xF800,  /* 111110000 */
    0xDC00,  /* 110111000 */
    0xCE00,  /* 110011100 */
    0xC700,  /* 110001110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=76, hex=0x4C, ascii="L"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=77, hex=0x4D, ascii="M"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0xE700,  /* 111001110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=78, hex=0x4E, ascii="N"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xE300,  /* 111000110 */
    0xE300,  /* 111000110 */
    0xF300,  /* 111100110 */
    0xF300,  /* 111100110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xCF00,  /* 110011110 */
    0xCF00,  /* 110011110 */
    0xC700,  /* 110001110 */
    0xC700,  /* 110001110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=79, hex=0x4F, ascii="O"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=80, hex=0x50, ascii="P"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFC00,  /* 111111000 */
    0xFE00,  /* 111111100 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xFE00,  /* 111111100 */
    0xFC00,  /* 111111000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=81, hex=0x51, ascii="Q"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3E00,  /* 001111100 */
    0x0700,  /* 000001110 */
    0x0000},  /* 000000000 */

    /*
     * code=82, hex=0x52, ascii="R"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFC00,  /* 111111000 */
    0xFE00,  /* 111111100 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xFE00,  /* 111111100 */
    0xFC00,  /* 111111000 */
    0xF800,  /* 111110000 */
    0xDC00,  /* 110111000 */
    0xCE00,  /* 110011100 */
    0xC700,  /* 110001110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=83, hex=0x53, ascii="S"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0xE300,  /* 111000110 */
    0xC000,  /* 110000000 */
    0xE000,  /* 111000000 */
    0x7C00,  /* 011111000 */
    0x3E00,  /* 001111100 */
    0x0700,  /* 000001110 */
    0x0300,  /* 000000110 */
    0xC700,  /* 110001110 */
    0xFE00,  /* 111111100 */
    0x7C00,  /* 011111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=84, hex=0x54, ascii="T"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=85, hex=0x55, ascii="U"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=86, hex=0x56, ascii="V"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0xE700,  /* 111001110 */
    0x6600,  /* 011001100 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=87, hex=0x57, ascii="W"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xE700,  /* 111001110 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=88, hex=0x58, ascii="X"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0x6600,  /* 011001100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=89, hex=0x59, ascii="Y"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=90, hex=0x5A, ascii="Z"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0700,  /* 000001110 */
    0x0E00,  /* 000011100 */
    0x0C00,  /* 000011000 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x3000,  /* 001100000 */
    0x7000,  /* 011100000 */
    0xE000,  /* 111000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=91, hex=0x5B, ascii="["
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=92, hex=0x5C, ascii="\"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x8000,  /* 100000000 */
    0xC000,  /* 110000000 */
    0xE000,  /* 111000000 */
    0x7000,  /* 011100000 */
    0x3800,  /* 001110000 */
    0x1C00,  /* 000111000 */
    0x0E00,  /* 000011100 */
    0x0700,  /* 000001110 */
    0x0300,  /* 000000110 */
    0x0100,  /* 000000010 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=93, hex=0x5D, ascii="]"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=94, hex=0x5E, ascii="^"
     */
    {0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=95, hex=0x5F, ascii="_"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000},  /* 000000000 */

    /*
     * code=96, hex=0x60, ascii="`"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=97, hex=0x61, ascii="a"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x3F00,  /* 001111110 */
    0x0300,  /* 000000110 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=98, hex=0x62, ascii="b"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x7E00,  /* 011111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x7E00,  /* 011111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=99, hex=0x63, ascii="c"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=100, hex=0x64, ascii="d"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=101, hex=0x65, ascii="e"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x6000,  /* 011000000 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=102, hex=0x66, ascii="f"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0F00,  /* 000011110 */
    0x1F00,  /* 000111110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=103, hex=0x67, ascii="g"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0700,  /* 000001110 */
    0x7E00,  /* 011111100 */
    0x3C00},  /* 001111000 */

    /*
     * code=104, hex=0x68, ascii="h"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x7E00,  /* 011111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=105, hex=0x69, ascii="i"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=106, hex=0x6A, ascii="j"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0000,  /* 000000000 */
    0x1E00,  /* 000111100 */
    0x1E00,  /* 000111100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0600,  /* 000001100 */
    0x0E00,  /* 000011100 */
    0x7C00,  /* 011111000 */
    0x7800},  /* 011110000 */

    /*
     * code=107, hex=0x6B, ascii="k"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6300,  /* 011000110 */
    0x6700,  /* 011001110 */
    0x6E00,  /* 011011100 */
    0x7C00,  /* 011111000 */
    0x7800,  /* 011110000 */
    0x7C00,  /* 011111000 */
    0x6E00,  /* 011011100 */
    0x6700,  /* 011001110 */
    0x6300,  /* 011000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=108, hex=0x6C, ascii="l"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=109, hex=0x6D, ascii="m"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xEE00,  /* 111011100 */
    0xFF00,  /* 111111110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=110, hex=0x6E, ascii="n"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7E00,  /* 011111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=111, hex=0x6F, ascii="o"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=112, hex=0x70, ascii="p"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7E00,  /* 011111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x7E00,  /* 011111100 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000},  /* 011000000 */

    /*
     * code=113, hex=0x71, ascii="q"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0x0300},  /* 000000110 */

    /*
     * code=114, hex=0x72, ascii="r"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6E00,  /* 011011100 */
    0x7F00,  /* 011111110 */
    0x7300,  /* 011100110 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=115, hex=0x73, ascii="s"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1E00,  /* 000111100 */
    0x3F00,  /* 001111110 */
    0x6300,  /* 011000110 */
    0x7800,  /* 011110000 */
    0x3E00,  /* 001111100 */
    0x0F00,  /* 000011110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=116, hex=0x74, ascii="t"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1F00,  /* 000111110 */
    0x0F00,  /* 000011110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=117, hex=0x75, ascii="u"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=118, hex=0x76, ascii="v"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=119, hex=0x77, ascii="w"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=120, hex=0x78, ascii="x"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=121, hex=0x79, ascii="y"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE600,  /* 111001100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x3800,  /* 001110000 */
    0xF000,  /* 111100000 */
    0xE000},  /* 111000000 */

    /*
     * code=122, hex=0x7A, ascii="z"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0700,  /* 000001110 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x7000,  /* 011100000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=123, hex=0x7B, ascii="{"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0700,  /* 000001110 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x1C00,  /* 000111000 */
    0x7800,  /* 011110000 */
    0x1C00,  /* 000111000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0700,  /* 000001110 */
    0x0000},  /* 000000000 */

    /*
     * code=124, hex=0x7C, ascii="|"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=125, hex=0x7D, ascii="}"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7000,  /* 011100000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1C00,  /* 000111000 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7000,  /* 011100000 */
    0x0000},  /* 000000000 */

    /*
     * code=126, hex=0x7E, ascii="~"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3B00,  /* 001110110 */
    0x6E00,  /* 011011100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=127, hex=0x7F, ascii="^?"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0800,  /* 000010000 */
    0x1C00,  /* 000111000 */
    0x3600,  /* 001101100 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=128, hex=0x80, ascii="!^@"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC300,  /* 110000110 */
    0xC700,  /* 110001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0E00,  /* 000011100 */
    0x7E00,  /* 011111100 */
    0x7C00},  /* 011111000 */

    /*
     * code=129, hex=0x81, ascii="!^A"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x0000,  /* 000000000 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=130, hex=0x82, ascii="!^B"
     */
    {0x0000,  /* 000000000 */
    0x0600,  /* 000001100 */
    0x0C00,  /* 000011000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x6000,  /* 011000000 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=131, hex=0x83, ascii="!^C"
     */
    {0x0000,  /* 000000000 */
    0x0C00,  /* 000011000 */
    0x1E00,  /* 000111100 */
    0x3300,  /* 001100110 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x3F00,  /* 001111110 */
    0x0300,  /* 000000110 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=132, hex=0x84, ascii="!^D"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3300,  /* 001100110 */
    0x3300,  /* 001100110 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x3F00,  /* 001111110 */
    0x0300,  /* 000000110 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=133, hex=0x85, ascii="!^E"
     */
    {0x0000,  /* 000000000 */
    0x3000,  /* 001100000 */
    0x1800,  /* 000110000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x3F00,  /* 001111110 */
    0x0300,  /* 000000110 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=134, hex=0x86, ascii="!^F"
     */
    {0x0000,  /* 000000000 */
    0x1C00,  /* 000111000 */
    0x3600,  /* 001101100 */
    0x1C00,  /* 000111000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x3F00,  /* 001111110 */
    0x0300,  /* 000000110 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=135, hex=0x87, ascii="!^G"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3C00,  /* 001111000 */
    0x0600,  /* 000001100 */
    0x3E00,  /* 001111100 */
    0x3C00},  /* 001111000 */

    /*
     * code=136, hex=0x88, ascii="!^H"
     */
    {0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x6000,  /* 011000000 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=137, hex=0x89, ascii="!^I"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x6000,  /* 011000000 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=138, hex=0x8A, ascii="!^J"
     */
    {0x0000,  /* 000000000 */
    0x3000,  /* 001100000 */
    0x1800,  /* 000110000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x6000,  /* 011000000 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=139, hex=0x8B, ascii="!^K"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=140, hex=0x8C, ascii="!^L"
     */
    {0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=141, hex=0x8D, ascii="!^M"
     */
    {0x0000,  /* 000000000 */
    0x3000,  /* 001100000 */
    0x1800,  /* 000110000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=142, hex=0x8E, ascii="!^N"
     */
    {0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=143, hex=0x8F, ascii="!^O"
     */
    {0x1800,  /* 000110000 */
    0x2400,  /* 001001000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=144, hex=0x90, ascii="!^P"
     */
    {0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xFE00,  /* 111111100 */
    0xFE00,  /* 111111100 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=145, hex=0x91, ascii="!^Q"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xF600,  /* 111101100 */
    0xFF00,  /* 111111110 */
    0x1900,  /* 000110010 */
    0x1900,  /* 000110010 */
    0x7F00,  /* 011111110 */
    0xD800,  /* 110110000 */
    0xD900,  /* 110110010 */
    0xFF00,  /* 111111110 */
    0x7600,  /* 011101100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=146, hex=0x92, ascii="!^R"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0xEC00,  /* 111011000 */
    0xCC00,  /* 110011000 */
    0xCC00,  /* 110011000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xCC00,  /* 110011000 */
    0xCC00,  /* 110011000 */
    0xCC00,  /* 110011000 */
    0xCF00,  /* 110011110 */
    0xCF00,  /* 110011110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=147, hex=0x93, ascii="!^S"
     */
    {0x0000,  /* 000000000 */
    0x0800,  /* 000010000 */
    0x1C00,  /* 000111000 */
    0x3600,  /* 001101100 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=148, hex=0x94, ascii="!^T"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=149, hex=0x95, ascii="!^U"
     */
    {0x0000,  /* 000000000 */
    0x3000,  /* 001100000 */
    0x1800,  /* 000110000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=150, hex=0x96, ascii="!^V"
     */
    {0x0000,  /* 000000000 */
    0x0800,  /* 000010000 */
    0x1C00,  /* 000111000 */
    0x3600,  /* 001101100 */
    0x0000,  /* 000000000 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=151, hex=0x97, ascii="!^W"
     */
    {0x0000,  /* 000000000 */
    0x3000,  /* 001100000 */
    0x1800,  /* 000110000 */
    0x0C00,  /* 000011000 */
    0x0000,  /* 000000000 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=152, hex=0x98, ascii="!^X"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE600,  /* 111001100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x3800,  /* 001110000 */
    0xF000,  /* 111100000 */
    0xE000},  /* 111000000 */

    /*
     * code=153, hex=0x99, ascii="!^Y"
     */
    {0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=154, hex=0x9A, ascii="!^Z"
     */
    {0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=155, hex=0x9B, ascii="!^["
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000},  /* 000000000 */

    /*
     * code=156, hex=0x9C, ascii="!^\"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1E00,  /* 000111100 */
    0x3300,  /* 001100110 */
    0x3300,  /* 001100110 */
    0x3000,  /* 001100000 */
    0x7C00,  /* 011111000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0xF300,  /* 111100110 */
    0xBE00,  /* 101111100 */
    0xF600,  /* 111101100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=157, hex=0x9D, ascii="!^]"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0xFF00,  /* 111111110 */
    0x1800,  /* 000110000 */
    0xFF00,  /* 111111110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=158, hex=0x9E, ascii="!^^"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFC00,  /* 111111000 */
    0xFE00,  /* 111111100 */
    0xC700,  /* 110001110 */
    0xC700,  /* 110001110 */
    0xFE00,  /* 111111100 */
    0xFC00,  /* 111111000 */
    0xC000,  /* 110000000 */
    0xC600,  /* 110001100 */
    0xCF00,  /* 110011110 */
    0xC600,  /* 110001100 */
    0xC600,  /* 110001100 */
    0xC700,  /* 110001110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=159, hex=0x9F, ascii="!^_"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0F00,  /* 000011110 */
    0x1B00,  /* 000110110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xD800,  /* 110110000 */
    0xF000,  /* 111100000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=160, hex=0xA0, ascii="! "
     */
    {0x0000,  /* 000000000 */
    0x0600,  /* 000001100 */
    0x0C00,  /* 000011000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x3F00,  /* 001111110 */
    0x0300,  /* 000000110 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=161, hex=0xA1, ascii="!!"
     */
    {0x0000,  /* 000000000 */
    0x0600,  /* 000001100 */
    0x0C00,  /* 000011000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x0C00,  /* 000011000 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=162, hex=0xA2, ascii="!""
     */
    {0x0000,  /* 000000000 */
    0x0600,  /* 000001100 */
    0x0C00,  /* 000011000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x3E00,  /* 001111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=163, hex=0xA3, ascii="!#"
     */
    {0x0000,  /* 000000000 */
    0x0600,  /* 000001100 */
    0x0C00,  /* 000011000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=164, hex=0xA4, ascii="!$"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3B00,  /* 001110110 */
    0x6E00,  /* 011011100 */
    0x0000,  /* 000000000 */
    0x7E00,  /* 011111100 */
    0x7F00,  /* 011111110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=165, hex=0xA5, ascii="!%"
     */
    {0x3B00,  /* 001110110 */
    0x6E00,  /* 011011100 */
    0x0000,  /* 000000000 */
    0xE300,  /* 111000110 */
    0xE300,  /* 111000110 */
    0xF300,  /* 111100110 */
    0xF300,  /* 111100110 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0xCF00,  /* 110011110 */
    0xCF00,  /* 110011110 */
    0xC700,  /* 110001110 */
    0xC700,  /* 110001110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=166, hex=0xA6, ascii="!&"
     */
    {0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x6C00,  /* 011011000 */
    0x6C00,  /* 011011000 */
    0x6C00,  /* 011011000 */
    0x3E00,  /* 001111100 */
    0x0000,  /* 000000000 */
    0x7E00,  /* 011111100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=167, hex=0xA7, ascii="!'"
     */
    {0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x7E00,  /* 011111100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=168, hex=0xA8, ascii="!("
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x0000,  /* 000000000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x3000,  /* 001100000 */
    0x6000,  /* 011000000 */
    0xE300,  /* 111000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=169, hex=0xA9, ascii="!)"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x6000,  /* 011000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=170, hex=0xAA, ascii="!*"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0x0300,  /* 000000110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=171, hex=0xAB, ascii="!+"
     */
    {0x0000,  /* 000000000 */
    0xC000,  /* 110000000 */
    0xC100,  /* 110000010 */
    0xC300,  /* 110000110 */
    0xC600,  /* 110001100 */
    0xCC00,  /* 110011000 */
    0xD800,  /* 110110000 */
    0x3000,  /* 001100000 */
    0x6E00,  /* 011011100 */
    0xDF00,  /* 110111110 */
    0x9B00,  /* 100110110 */
    0x0300,  /* 000000110 */
    0x0600,  /* 000001100 */
    0x0F00,  /* 000011110 */
    0x1F00,  /* 000111110 */
    0x0000},  /* 000000000 */

    /*
     * code=172, hex=0xAC, ascii="!,"
     */
    {0x0000,  /* 000000000 */
    0xC000,  /* 110000000 */
    0xC100,  /* 110000010 */
    0xC300,  /* 110000110 */
    0xC600,  /* 110001100 */
    0xCC00,  /* 110011000 */
    0xD800,  /* 110110000 */
    0x3000,  /* 001100000 */
    0x6700,  /* 011001110 */
    0xCF00,  /* 110011110 */
    0x9B00,  /* 100110110 */
    0x1B00,  /* 000110110 */
    0x1F00,  /* 000111110 */
    0x1F00,  /* 000111110 */
    0x0300,  /* 000000110 */
    0x0000},  /* 000000000 */

    /*
     * code=173, hex=0xAD, ascii="!-"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x0000},  /* 000000000 */

    /*
     * code=174, hex=0xAE, ascii="!."
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3300,  /* 001100110 */
    0x6600,  /* 011001100 */
    0xCC00,  /* 110011000 */
    0x6600,  /* 011001100 */
    0x3300,  /* 001100110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=175, hex=0xAF, ascii="!/"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xCC00,  /* 110011000 */
    0x6600,  /* 011001100 */
    0x3300,  /* 001100110 */
    0x6600,  /* 011001100 */
    0xCC00,  /* 110011000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=176, hex=0xB0, ascii="!0"
     */
    {0x2200,  /* 001000100 */
    0x8800,  /* 100010000 */
    0x2200,  /* 001000100 */
    0x8800,  /* 100010000 */
    0x2200,  /* 001000100 */
    0x8800,  /* 100010000 */
    0x2200,  /* 001000100 */
    0x8800,  /* 100010000 */
    0x2200,  /* 001000100 */
    0x8800,  /* 100010000 */
    0x2200,  /* 001000100 */
    0x8800,  /* 100010000 */
    0x2200,  /* 001000100 */
    0x8800,  /* 100010000 */
    0x2200,  /* 001000100 */
    0x8800},  /* 100010000 */

    /*
     * code=177, hex=0xB1, ascii="!1"
     */
    {0xAA00,  /* 101010100 */
    0x5400,  /* 010101000 */
    0xAA00,  /* 101010100 */
    0x5400,  /* 010101000 */
    0xAA00,  /* 101010100 */
    0x5400,  /* 010101000 */
    0xAA00,  /* 101010100 */
    0x5400,  /* 010101000 */
    0xAA00,  /* 101010100 */
    0x5400,  /* 010101000 */
    0xAA00,  /* 101010100 */
    0x5400,  /* 010101000 */
    0xAA00,  /* 101010100 */
    0x5400,  /* 010101000 */
    0xAA00,  /* 101010100 */
    0x5400},  /* 010101000 */

    /*
     * code=178, hex=0xB2, ascii="!2"
     */
    {0xBB00,  /* 101110110 */
    0xEE00,  /* 111011100 */
    0xBB00,  /* 101110110 */
    0xEE00,  /* 111011100 */
    0xBB00,  /* 101110110 */
    0xEE00,  /* 111011100 */
    0xBB00,  /* 101110110 */
    0xEE00,  /* 111011100 */
    0xBB00,  /* 101110110 */
    0xEE00,  /* 111011100 */
    0xBB00,  /* 101110110 */
    0xEE00,  /* 111011100 */
    0xBB00,  /* 101110110 */
    0xEE00,  /* 111011100 */
    0xBB00,  /* 101110110 */
    0xEE00},  /* 111011100 */

    /*
     * code=179, hex=0xB3, ascii="!3"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=180, hex=0xB4, ascii="!4"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xF800,  /* 111110000 */
    0xF800,  /* 111110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=181, hex=0xB5, ascii="!5"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xF800,  /* 111110000 */
    0xF800,  /* 111110000 */
    0x1800,  /* 000110000 */
    0xF800,  /* 111110000 */
    0xF800,  /* 111110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=182, hex=0xB6, ascii="!6"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0xF600,  /* 111101100 */
    0xF600,  /* 111101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=183, hex=0xB7, ascii="!7"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFE00,  /* 111111100 */
    0xFE00,  /* 111111100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=184, hex=0xB8, ascii="!8"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xF800,  /* 111110000 */
    0xF800,  /* 111110000 */
    0x1800,  /* 000110000 */
    0xF800,  /* 111110000 */
    0xF800,  /* 111110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=185, hex=0xB9, ascii="!9"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0xF600,  /* 111101100 */
    0xF600,  /* 111101100 */
    0x0600,  /* 000001100 */
    0xF600,  /* 111101100 */
    0xF600,  /* 111101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=186, hex=0xBA, ascii="!:"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=187, hex=0xBB, ascii="!;"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFE00,  /* 111111100 */
    0xFE00,  /* 111111100 */
    0x0600,  /* 000001100 */
    0xF600,  /* 111101100 */
    0xF600,  /* 111101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=188, hex=0xBC, ascii="!<"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0xF600,  /* 111101100 */
    0xF600,  /* 111101100 */
    0x0600,  /* 000001100 */
    0xFE00,  /* 111111100 */
    0xFE00,  /* 111111100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=189, hex=0xBD, ascii="!="
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0xFE00,  /* 111111100 */
    0xFE00,  /* 111111100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=190, hex=0xBE, ascii="!>"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xF800,  /* 111110000 */
    0xF800,  /* 111110000 */
    0x1800,  /* 000110000 */
    0xF800,  /* 111110000 */
    0xF800,  /* 111110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=191, hex=0xBF, ascii="!?"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xF800,  /* 111110000 */
    0xF800,  /* 111110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=192, hex=0xC0, ascii="!@"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1F80,  /* 000111111 */
    0x1F80,  /* 000111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=193, hex=0xC1, ascii="!A"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=194, hex=0xC2, ascii="!B"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=195, hex=0xC3, ascii="!C"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1F80,  /* 000111111 */
    0x1F80,  /* 000111111 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=196, hex=0xC4, ascii="!D"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=197, hex=0xC5, ascii="!E"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=198, hex=0xC6, ascii="!F"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1F80,  /* 000111111 */
    0x1F80,  /* 000111111 */
    0x1800,  /* 000110000 */
    0x1F80,  /* 000111111 */
    0x1F80,  /* 000111111 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=199, hex=0xC7, ascii="!G"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3780,  /* 001101111 */
    0x3780,  /* 001101111 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=200, hex=0xC8, ascii="!H"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3780,  /* 001101111 */
    0x3780,  /* 001101111 */
    0x3000,  /* 001100000 */
    0x3F80,  /* 001111111 */
    0x3F80,  /* 001111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=201, hex=0xC9, ascii="!I"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3F80,  /* 001111111 */
    0x3F80,  /* 001111111 */
    0x3000,  /* 001100000 */
    0x3780,  /* 001101111 */
    0x3780,  /* 001101111 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=202, hex=0xCA, ascii="!J"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0xF780,  /* 111101111 */
    0xF780,  /* 111101111 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=203, hex=0xCB, ascii="!K"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0xF780,  /* 111101111 */
    0xF780,  /* 111101111 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=204, hex=0xCC, ascii="!L"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3780,  /* 001101111 */
    0x3780,  /* 001101111 */
    0x3000,  /* 001100000 */
    0x3780,  /* 001101111 */
    0x3780,  /* 001101111 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=205, hex=0xCD, ascii="!M"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=206, hex=0xCE, ascii="!N"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0xF780,  /* 111101111 */
    0xF780,  /* 111101111 */
    0x0000,  /* 000000000 */
    0xF780,  /* 111101111 */
    0xF780,  /* 111101111 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=207, hex=0xCF, ascii="!O"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=208, hex=0xD0, ascii="!P"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=209, hex=0xD1, ascii="!Q"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=210, hex=0xD2, ascii="!R"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=211, hex=0xD3, ascii="!S"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3F80,  /* 001111111 */
    0x3F80,  /* 001111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=212, hex=0xD4, ascii="!T"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1F80,  /* 000111111 */
    0x1F80,  /* 000111111 */
    0x1800,  /* 000110000 */
    0x1F80,  /* 000111111 */
    0x1F80,  /* 000111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=213, hex=0xD5, ascii="!U"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1F80,  /* 000111111 */
    0x1F80,  /* 000111111 */
    0x1800,  /* 000110000 */
    0x1F80,  /* 000111111 */
    0x1F80,  /* 000111111 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=214, hex=0xD6, ascii="!V"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3F80,  /* 001111111 */
    0x3F80,  /* 001111111 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=215, hex=0xD7, ascii="!W"
     */
    {0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600,  /* 001101100 */
    0x3600},  /* 001101100 */

    /*
     * code=216, hex=0xD8, ascii="!X"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x1800,  /* 000110000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=217, hex=0xD9, ascii="!Y"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xF800,  /* 111110000 */
    0xF800,  /* 111110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=218, hex=0xDA, ascii="!Z"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1F80,  /* 000111111 */
    0x1F80,  /* 000111111 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800},  /* 000110000 */

    /*
     * code=219, hex=0xDB, ascii="!["
     */
    {0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80},  /* 111111111 */

    /*
     * code=220, hex=0xDC, ascii="!\"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80},  /* 111111111 */

    /*
     * code=221, hex=0xDD, ascii="!]"
     */
    {0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000,  /* 111100000 */
    0xF000},  /* 111100000 */

    /*
     * code=222, hex=0xDE, ascii="!^"
     */
    {0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80,  /* 000011111 */
    0x0F80},  /* 000011111 */

    /*
     * code=223, hex=0xDF, ascii="!_"
     */
    {0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0xFF80,  /* 111111111 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=224, hex=0xE0, ascii="!`"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3100,  /* 001100010 */
    0x7B00,  /* 011110110 */
    0xCF00,  /* 110011110 */
    0xCE00,  /* 110011100 */
    0xCC00,  /* 110011000 */
    0xCE00,  /* 110011100 */
    0xCF00,  /* 110011110 */
    0x7B00,  /* 011110110 */
    0x3100,  /* 001100010 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=225, hex=0xE1, ascii="!a"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3800,  /* 001110000 */
    0x7C00,  /* 011111000 */
    0xEE00,  /* 111011100 */
    0xC600,  /* 110001100 */
    0xC600,  /* 110001100 */
    0xDC00,  /* 110111000 */
    0xDE00,  /* 110111100 */
    0xC700,  /* 110001110 */
    0xC300,  /* 110000110 */
    0xE300,  /* 111000110 */
    0xFE00,  /* 111111100 */
    0xDC00,  /* 110111000 */
    0xC000,  /* 110000000 */
    0x0000},  /* 000000000 */

    /*
     * code=226, hex=0xE2, ascii="!b"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0xC000,  /* 110000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=227, hex=0xE3, ascii="!c"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=228, hex=0xE4, ascii="!d"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xE000,  /* 111000000 */
    0x7000,  /* 011100000 */
    0x3800,  /* 001110000 */
    0x1C00,  /* 000111000 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x7000,  /* 011100000 */
    0xE000,  /* 111000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=229, hex=0xE5, ascii="!e"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0x6C00,  /* 011011000 */
    0xC600,  /* 110001100 */
    0xC600,  /* 110001100 */
    0xC600,  /* 110001100 */
    0xEE00,  /* 111011100 */
    0x7C00,  /* 011111000 */
    0x3800,  /* 001110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=230, hex=0xE6, ascii="!f"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6700,  /* 011001110 */
    0x7E00,  /* 011111100 */
    0x7C00,  /* 011111000 */
    0x6000,  /* 011000000 */
    0xE000,  /* 111000000 */
    0x0000},  /* 000000000 */

    /*
     * code=231, hex=0xE7, ascii="!g"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7300,  /* 011100110 */
    0xDE00,  /* 110111100 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=232, hex=0xE8, ascii="!h"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7E00,  /* 011111100 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x1800,  /* 000110000 */
    0x7E00,  /* 011111100 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=233, hex=0xE9, ascii="!i"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=234, hex=0xEA, ascii="!j"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0xE700,  /* 111001110 */
    0xE700,  /* 111001110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=235, hex=0xEB, ascii="!k"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1E00,  /* 000111100 */
    0x3E00,  /* 001111100 */
    0x3000,  /* 001100000 */
    0x1800,  /* 000110000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xE700,  /* 111001110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=236, hex=0xEC, ascii="!l"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x6600,  /* 011001100 */
    0xDB00,  /* 110110110 */
    0xDB00,  /* 110110110 */
    0x6600,  /* 011001100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=237, hex=0xED, ascii="!m"
     */
    {0x0000,  /* 000000000 */
    0x0E00,  /* 000011100 */
    0x1E00,  /* 000111100 */
    0x3000,  /* 001100000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xF700,  /* 111101110 */
    0xD300,  /* 110100110 */
    0xCB00,  /* 110010110 */
    0xEF00,  /* 111011110 */
    0x7E00,  /* 011111100 */
    0x3C00,  /* 001111000 */
    0x0C00,  /* 000011000 */
    0x7800,  /* 011110000 */
    0x7000,  /* 011100000 */
    0x0000},  /* 000000000 */

    /*
     * code=238, hex=0xEE, ascii="!n"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3F00,  /* 001111110 */
    0x7F00,  /* 011111110 */
    0xE000,  /* 111000000 */
    0xC000,  /* 110000000 */
    0xFE00,  /* 111111100 */
    0xFE00,  /* 111111100 */
    0xC000,  /* 110000000 */
    0xE000,  /* 111000000 */
    0x7F00,  /* 011111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=239, hex=0xEF, ascii="!o"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0xE700,  /* 111001110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0xC300,  /* 110000110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=240, hex=0xF0, ascii="!p"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=241, hex=0xF1, ascii="!q"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=242, hex=0xF2, ascii="!r"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7000,  /* 011100000 */
    0x3800,  /* 001110000 */
    0x1C00,  /* 000111000 */
    0x0E00,  /* 000011100 */
    0x0700,  /* 000001110 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x7000,  /* 011100000 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=243, hex=0xF3, ascii="!s"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0700,  /* 000001110 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x7000,  /* 011100000 */
    0x3800,  /* 001110000 */
    0x1C00,  /* 000111000 */
    0x0E00,  /* 000011100 */
    0x0700,  /* 000001110 */
    0x0000,  /* 000000000 */
    0x7F00,  /* 011111110 */
    0x7F00,  /* 011111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=244, hex=0xF4, ascii="!t"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0E00,  /* 000011100 */
    0x1F00,  /* 000111110 */
    0x1B00,  /* 000110110 */
    0x1B00,  /* 000110110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=245, hex=0xF5, ascii="!u"
     */
    {0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xD800,  /* 110110000 */
    0xD800,  /* 110110000 */
    0xF800,  /* 111110000 */
    0x7000,  /* 011100000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=246, hex=0xF6, ascii="!v"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0xFF00,  /* 111111110 */
    0xFF00,  /* 111111110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=247, hex=0xF7, ascii="!w"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x7B00,  /* 011110110 */
    0xDE00,  /* 110111100 */
    0x0000,  /* 000000000 */
    0x7B00,  /* 011110110 */
    0xDE00,  /* 110111100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=248, hex=0xF8, ascii="!x"
     */
    {0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x6600,  /* 011001100 */
    0x3C00,  /* 001111000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=249, hex=0xF9, ascii="!y"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=250, hex=0xFA, ascii="!z"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=251, hex=0xFB, ascii="!{"
     */
    {0x0000,  /* 000000000 */
    0x1F00,  /* 000111110 */
    0x1F00,  /* 000111110 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0xD800,  /* 110110000 */
    0xD800,  /* 110110000 */
    0x7800,  /* 011110000 */
    0x7800,  /* 011110000 */
    0x3800,  /* 001110000 */
    0x3800,  /* 001110000 */
    0x1800,  /* 000110000 */
    0x1800,  /* 000110000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=252, hex=0xFC, ascii="!|"
     */
    {0x0000,  /* 000000000 */
    0x6E00,  /* 011011100 */
    0x7F00,  /* 011111110 */
    0x7300,  /* 011100110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x6300,  /* 011000110 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=253, hex=0xFD, ascii="!}"
     */
    {0x0000,  /* 000000000 */
    0x3C00,  /* 001111000 */
    0x7E00,  /* 011111100 */
    0x6600,  /* 011001100 */
    0x0E00,  /* 000011100 */
    0x1C00,  /* 000111000 */
    0x3800,  /* 001110000 */
    0x7E00,  /* 011111100 */
    0x7E00,  /* 011111100 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=254, hex=0xFE, ascii="!~"
     */
    {0x0000,  /* 000000000 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x3F00,  /* 001111110 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */

    /*
     * code=255, hex=0xFF, ascii="!^?"
     */
    {0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000,  /* 000000000 */
    0x0000},  /* 000000000 */
};

	
	
/*******************************************************************************
* Function Name : void OLED_DELAY(vu32 nCount)
* Description   : Microsecond delay
* Parameters    : Microsecond conunt
* Return        : None
*******************************************************************************/
void OLED_DELAY(vu32 nCount)
{
#if 0
	nCount *= 1;
    for(; nCount!=0; nCount--);
#else
	__ASM volatile ("nop"); 
#endif
}

/*
NCS PA2
NRES PA3
DNC PA4
SCLK PA5
SDIN PA7
*/

/*******************************************************************************
* Function Name : 
* Parameters    : 
* Return        : none
* Description   : 
*******************************************************************************/
void OLED_EN(FunctionalState NewState)
{
  if (NewState == DISABLE){
//    GPIO_ResetBits(GPIOA, GPIO_Pin_10);
  }
  else{
//    GPIO_SetBits(GPIOA, GPIO_Pin_10);
  }
}

/*******************************************************************************
* Function Name : 
* Parameters    : 
* Return        : none
* Description   : 
This pin is reset signal input.
When the pin is pulled LOW, initialization of the chip is executed.
Keep this pin pull HIGH during normal operation.
*******************************************************************************/
void OLED_RES(FunctionalState NewState)
{
  if (NewState == DISABLE){
    GPIO_ResetBits(GPIOA, GPIO_Pin_3);
  }
  else{
    GPIO_SetBits(GPIOA, GPIO_Pin_3);
  }
}


typedef enum 
{
	eOLEDCMD = 0,
	eOLEDDAT = 1
}OLEDCmdStatus;

/*******************************************************************************
* Function Name : 
* Parameters    : 
* Return        : none
* Description   : 
high = Data
low = Command
*******************************************************************************/
static void OLED_DC(OLEDCmdStatus NewState)
{
  if (NewState == eOLEDCMD){
    GPIO_ResetBits(GPIOA, GPIO_Pin_4);
  }
  else{
    GPIO_SetBits(GPIOA, GPIO_Pin_4);
  }
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
void SPI_OLED_CS_HIGH(void) 
{
	GPIO_SetBits(GPIOA, GPIO_Pin_2);
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
void SPI_OLED_CS_LOW(void) 	
{
	GPIO_ResetBits(GPIOA, GPIO_Pin_2);
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
uint8_t SPI_FLASH_SendByte(uint8_t byte, u8 softspi)
{
	uint8_t RXDat = 0;

		uint8_t	SPI_count;        

		for (SPI_count = 0; SPI_count < 8; SPI_count++)
		{      
			if((byte & 0x80) == 0x80){
				GPIO_SetBits(GPIOA, GPIO_Pin_7);//MOSI HIGH
			}
			else{
				GPIO_ResetBits(GPIOA, GPIO_Pin_7); //MOSI LOW
			}
	 
			byte = byte << 1;        // shift next bit into MSB      
			OLED_DELAY(2);
			
			GPIO_SetBits(GPIOA, GPIO_Pin_5);//SCK HIGH
			OLED_DELAY(3);
			 
			GPIO_ResetBits(GPIOA, GPIO_Pin_5);//SCK LOW   
			OLED_DELAY(2);
		}
	/* Read SPIz received data */
	return RXDat;	
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
void OLED_CMD(uint8_t data){
	OLED_DC(eOLEDCMD);//	GPIO_ResetBits(GPIOA, GPIO_Pin_14);
	OLED_DELAY(5);
	SPI_OLED_CS_LOW();
	OLED_DELAY(5);
	SPI_FLASH_SendByte(data, SW_SPI);
	OLED_DELAY(7);
	SPI_OLED_CS_HIGH();
	OLED_DELAY(10);	
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
void OLED_DAT(uint8_t data){
	OLED_DC(eOLEDDAT);//	GPIO_SetBits(GPIOA, GPIO_Pin_14);
	OLED_DELAY(5);
	SPI_OLED_CS_LOW();
	OLED_DELAY(5);
	SPI_FLASH_SendByte(data, SW_SPI);
	OLED_DELAY(7);
	SPI_OLED_CS_HIGH();
	OLED_DELAY(10);		
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
void OLED_ON(void)
{
	OLED_CMD(0xAF);
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
void OLED_OFF(void)
{
	OLED_CMD(0xAE);
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
0 ~ F =. 0 ~ 16
*******************************************************************************/
void OLED_CLEAR(const u8 sColor)
{
	u8 X, Y, Color = 0;
	
	Color = (sColor & 0x0F);
	Color ^= (sColor << 4);
	
	OLED_CMD(0xA1); // Set Display Start Line
	OLED_CMD(0x00);
	
	OLED_CMD(0x15); // Set Column Address
	OLED_CMD(0x00);
	OLED_CMD((MAX_WIDTH/2) - 1);

	OLED_CMD(0x75); // Set Row Address
	OLED_CMD(0x00);
	OLED_CMD(MAX_HEIGHT-1);	
		
	for(Y = 0 ; Y < MAX_HEIGHT ; Y++){
		for(X = 0; X < MAX_WIDTH/2 ; X++){//1 DRAW, 2 PIXEL
			OLED_DAT(Color);
		}
	}
	OLED_CMD(0xAF); // Set Display ON	
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
sColor 0 ~ F
*******************************************************************************/
void OLED_XLINE(u8 X, u8 Y, u8 Size, const u8 sColor)	
{
	__IO u8 Quotient, Remainder,  Color = 0;
	__IO u8 QuotientSize, RemainderSize;
	__IO u8 XL;
	
	if ((X + Size)  >= MAX_WIDTH) return ;
	
	/* PIXEL START */
	Quotient = X / 2;
	Remainder = X % 2;
	
	/* PIXEL END */
	QuotientSize = Size / 2;
	RemainderSize = Size % 2;	
	if(RemainderSize != 0)
		QuotientSize += 1;
	
//	DEBUGPRINT("%d, %d, %d\r\n", Size, Quotient, Remainder);	
//	DEBUGPRINT("%d, %d\r\n", QuotientSize, RemainderSize);	
	
	OLED_CMD(0x15); // Set Column Address
	OLED_CMD(Quotient);
	OLED_CMD(Quotient+QuotientSize-1);	

	OLED_CMD(0x75); // Set Row Address
	OLED_CMD(Y);
	OLED_CMD(Y);		
		
	for(XL = 0; XL < QuotientSize ; XL++){//1 DRAW, 2 PIXEL
		if(XL == 0){
			if(Remainder == 0){
				Color = ((sColor << 4) | sColor);
			}
			else{
				Color = (sColor & 0x0F);
			}			
		}
		else if(XL == (QuotientSize-1)){
			if(RemainderSize == 0 || Remainder !=0){
				Color = ((sColor << 4) | sColor);
			}
			else{
				Color = ((sColor << 4));
			}			
		}
		else{
			Color = ((sColor << 4) | sColor);
		}	
//		DEBUGPRINT("%02X\r\n", Color);	

		OLED_DAT(Color);
	}
}


/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
sColor 0 ~ F
*******************************************************************************/
void OLED_YLINE(u8 X, u8 Y, u8 Size, const u8 sColor)	
{
	__IO u8 Quotient, Remainder,  Color = 0;
	__IO u8 QuotientSize, RemainderSize;
	__IO u8 YL;
	
	if ((Y + Size)  >= MAX_HEIGHT) return ;
	
	/* PIXEL START */
	Quotient = X / 2;
	Remainder = X % 2;
	
	if(Remainder == 0){
		Color = (sColor << 4);
		Color = (Color & 0xF0);
	}
	else{
		Color = (sColor & 0x0F);
	}
	
//	DEBUGPRINT("%d, %d, %d\r\n", Size, Quotient, Remainder);	
//	DEBUGPRINT("%d, %d\r\n", QuotientSize, RemainderSize);	
	
	OLED_CMD(0x15); // Set Column Address
	OLED_CMD(Quotient);
	OLED_CMD(Quotient);		

	OLED_CMD(0x75); // Set Row Address
	OLED_CMD(Y);
	OLED_CMD(Y+Size-1);	
		
	for(YL = 0; YL < Size ; YL++){//1 DRAW, 2 PIXEL
		OLED_DAT(Color);
	}
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
sColor 0 ~ F
*******************************************************************************/
void OLED_RECTANGLE(u8 X, u8 Y, u8 XSize, u8 YSize, const u8 sColor)	
{
	__IO u8 Quotient, Remainder,  Color = 0;
	__IO u8 QuotientSize, RemainderSize;
	__IO u8 XL, YL;
	
	if (((X + XSize)  >= MAX_WIDTH) || ((Y + YSize)  >= MAX_HEIGHT)) return ;
		
	/* PIXEL START */
	Quotient = X / 2;
	Remainder = X % 2;
	
	/* PIXEL END */
	QuotientSize = XSize / 2;
	RemainderSize = XSize % 2;	
	if(RemainderSize != 0)
		QuotientSize += 1;
	
//	DEBUGPRINT("%d, %d, %d\r\n", Size, Quotient, Remainder);	
//	DEBUGPRINT("%d, %d\r\n", QuotientSize, RemainderSize);	
	
	OLED_CMD(0x15); // Set Column Address
	OLED_CMD(Quotient);
	OLED_CMD(Quotient+QuotientSize-1);	

	OLED_CMD(0x75); // Set Row Address
	OLED_CMD(Y);
	OLED_CMD(Y+YSize-1);		
		
	for(YL = 0 ; YL < YSize ; YL++){
		for(XL = 0; XL < QuotientSize ; XL++){//1 DRAW, 2 PIXEL
			if(XL == 0){
				if(Remainder == 0){
					Color = ((sColor << 4) | sColor);
				}
				else{
					Color = (sColor & 0x0F);
				}			
			}
			else if(XL == (QuotientSize-1)){
				if(RemainderSize == 0 || Remainder !=0){
					Color = ((sColor << 4) | sColor);
				}
				else{
					Color = ((sColor << 4));
				}			
			}
			else{
				Color = ((sColor << 4) | sColor);
			}	
			OLED_DAT(Color);
		}
	}
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
sColor 0 ~ F
*******************************************************************************/
void OLED_WINDOW(u8 X, u8 Y, u8 XSize, u8 YSize, const u8 sColor, const u8 sBGColor)	
{
	__IO u8 Quotient, Remainder,  Color = 0;
	__IO u8 QuotientSize, RemainderSize;
	__IO u8 XL, YL;
	
	if (((X + XSize)  >= MAX_WIDTH) || ((Y + YSize)  >= MAX_HEIGHT)) return ;
		
	/* PIXEL START */
	Quotient = X / 2;
	Remainder = X % 2;
	
	/* PIXEL END */
	QuotientSize = XSize / 2;
	RemainderSize = XSize % 2;	
	if(RemainderSize != 0)
		QuotientSize += 1;
	
//	DEBUGPRINT("%d, %d, %d\r\n", Size, Quotient, Remainder);	
//	DEBUGPRINT("%d, %d\r\n", QuotientSize, RemainderSize);	
	
	OLED_CMD(0x15); // Set Column Address
	OLED_CMD(Quotient);
	OLED_CMD(Quotient+QuotientSize-1);	

	OLED_CMD(0x75); // Set Row Address
	OLED_CMD(Y);
	OLED_CMD(Y+YSize-1);		
		
	for(YL = 0 ; YL < YSize ; YL++){
		for(XL = 0; XL < QuotientSize ; XL++){//1 DRAW, 2 PIXEL
			if(XL == 0){
				if(Remainder == 0){					
					if(YL == 0 || YL == (YSize-1)){
						Color = ((sColor << 4) | sColor);
					}
					else{
						Color = ((sColor << 4) & 0xF0);
					}
				}
				else{
					Color = (sColor & 0x0F);
				}			
			}
			else if(XL == (QuotientSize-1)){
				if(RemainderSize == 0 || Remainder !=0){
					if(YL == 0 || YL == (YSize-1)){
						Color = ((sColor << 4) | sColor);
					}
					else{
						Color = (sColor & 0x0F);
					}
				}
				else{
					Color = ((sColor << 4));
				}			
			}
			else{
				if(YL == 0 || YL == (YSize-1)){
					Color = ((sColor << 4) | sColor);
				}
				else{
					Color = sBGColor;
				}
			}			
			OLED_DAT(Color);
		}
	}
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
sColor 0 ~ F
*******************************************************************************/
void OLED_PIXEL(u8 X, u8 Y, const u8 sColor)
{
	u8 Quotient, Remainder,  Color = 0;
	
	if ((X >= MAX_WIDTH)||(Y >= MAX_HEIGHT)) return ;

	Quotient = X / 2;
	Remainder = X % 2;
	
	if(Remainder == 0){
		Color = (sColor << 4);
		Color = (Color & 0xF0);
	}
	else{
		Color = (sColor & 0x0F);
	}
//	DEBUGPRINT("%d, %d, %02X\r\n", Quotient, Remainder, Color);
		
	OLED_CMD(0x15); // Set Column Address
	OLED_CMD(Quotient);
	OLED_CMD(Quotient);	

	OLED_CMD(0x75); // Set Row Address
	OLED_CMD(Y);
	OLED_CMD(Y);	

	OLED_DAT(Color);
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
    eNORMALDISP      = 0x00,
    eALLONDISP        = 0x01,
    eALLOFFDISP        = 0x02,
    eINVERSEDISP        = 0x03
*******************************************************************************/
void OLED_EN_INVERT(u8 EnMODE)
{
    if(EnMODE == eNORMALDISP){
			OLED_CMD(0xA4);
		}
    else if(EnMODE == eALLONDISP){
			OLED_CMD(0xA5);
		}
    else if(EnMODE == eALLOFFDISP){
			OLED_CMD(0xA6);
		}
    else{
			OLED_CMD(0xA7);
		}		
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
void OLED_EN_FADE(u8 EnMODE, u8 sSpeed)
{
	u8 Speed = 0;
	
	if(sSpeed > 0x0F)
		sSpeed = 0x0F;
	
	sSpeed = (sSpeed & 0x0F);
	Speed = (0x0F - sSpeed);
	
	OLED_CMD(0x23);

	if(EnMODE == eFADEOUT){
		OLED_CMD(0x20 | Speed);
	}
	else{
		OLED_CMD(0x10 | Speed);
	}		
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Column_Address(unsigned char a_chStartCAddr, unsigned char a_chEndCAddr)
{
	OLED_CMD(0x15);			// Set Column Address
	OLED_CMD(a_chStartCAddr);			//Start Column Address   Default => 0x00
	OLED_CMD(a_chEndCAddr);			//End Column Address   Default => 0x3F (Total Columns Devided by 2)
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Row_Address(unsigned char a_chStartRAddr, unsigned char a_chEndRAddr)
{
	OLED_CMD(0x75);			// Set Row Address
	OLED_CMD(a_chStartRAddr);			//Satrt Row Address   Default => 0x00
	OLED_CMD(a_chEndRAddr);			//End Row Address  Default => 0x4F
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Display_On_Off(unsigned char d)
{
	OLED_CMD(0xAE|d);			// Set Display On/Off
						//   Default => 0xAE
						//     0xAE (0x00) => Display Off
						//     0xAF (0x01) => Display On
}


/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Display_Clock(unsigned char d)
{
	OLED_CMD(0xB3);			// Display Clock Divider/Osciallator Frequency
	OLED_CMD(d);			//   Default => 0x41
						//     D[3:0] => Display Clock Divider
						//     D[7:4] => Oscillator Frequency
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Multiplex_Ratio(unsigned char d)
{
	OLED_CMD(0xA8);			// Set Multiplex Ratio
	OLED_CMD(d);			//   Default => 0x5F
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Display_Offset(unsigned char d)
{
	OLED_CMD(0xA2);			// Set Display Offset
	OLED_CMD(d);			//   Vertical Scroll Default => 0x00
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Start_Line(unsigned char d)
{
	OLED_CMD(0xA1);			// Set Display Start Line
	OLED_CMD(d);			//   Default => 0x00
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Remap_Format(unsigned char d)
{
	OLED_CMD(0xA0);			// Set Re-Map & Data Format
	OLED_CMD(d);			//   Default => 0x00
						//     Column Address 0 Mapped to SEG0
						//     Disable Nibble Re-Map
						//     Horizontal Address Increment
						//     Scan from COM0 to COM[N-1]
						//     Disable COM Split Odd Even
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Phase_Length(unsigned char d)
{
	OLED_CMD(0xB1);			// Phase 1 & 2 Period Adjustment
	OLED_CMD(d);			//   Default => 0x53 (5 Display Clocks [Phase 2] / 3 Display Clocks [Phase 1])
						//     D[3:0] => Phase 1 Period in 1~15 Display Clocks
						//     D[7:4] => Phase 2 Period in 1~15 Display Clocks
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Precharge_Voltage(unsigned char d)
{
	OLED_CMD(0xBC);			// Set Pre-Charge Voltage Level
	OLED_CMD(d);			//   Default => 0x10 (Connect to VCOMH)
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_VCOMH(unsigned char d)
{
	OLED_CMD(0xBE);			// Set Output Level High Voltage for COM Signal
	OLED_CMD(d);			//   Default => 0x1D (0.82*VREF)
}


/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Display_Mode(unsigned char d)
{
	OLED_CMD(0xA4|d);			// Set Display Mode
						//   Default => 0xA4
						//     0xA4 (0x00) => Normal Display
						//     0xA5 (0x01) => Entire Display On, All Pixels Turn On at GS Level 15
						//     0xA6 (0x02) => Entire Display Off, All Pixels Turn Off
						//     0xA7 (0x03) => Inverse Display
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Set_Contrast_Current(unsigned char d)
{
	OLED_CMD(0x81);			// Set Contrast Value
	OLED_CMD(d);			//   Default => 0x40
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void Show_dot(u8 X, u8 Y, u8 sColor)
{	
	u8 Quotient, Remainder,  Color = 0;
	
	if ((X >= MAX_WIDTH)||(Y >= MAX_HEIGHT)) return ;
		
	OLED_CMD(0x15); // Set Column Address
	OLED_CMD(X);
	OLED_CMD(X);	

	OLED_CMD(0x75); // Set Row Address
	OLED_CMD(Y);
	OLED_CMD(Y);	

	OLED_DAT(sColor);	
}

/*******************************************************************************
* Function Name : 
* Description   : Draw Char
* Parameters    : 
* Return        : None
		Show_dot(6, 25, 0x0F);
		Show_dot(7, 25, 0x00);
		Show_dot(8, 25, 0x0F);
		Show_dot(9, 25, 0xF0);

		Show_dot(6, 26, 0x0F);
		Show_dot(7, 26, 0x00);
		Show_dot(8, 26, 0xF0);
		Show_dot(9, 26, 0x0F);

		Show_dot(6, 27, 0x0F);
		Show_dot(7, 27, 0x00);
		Show_dot(8, 27, 0xF0);
		Show_dot(9, 27, 0x0F);

		Show_dot(6, 28, 0x0F);
		Show_dot(7, 28, 0x00);
		Show_dot(8, 28, 0xF0);
		Show_dot(9, 28, 0x0F);

		Show_dot(6, 29, 0x00);
		Show_dot(7, 29, 0xFF);
		Show_dot(8, 29, 0x00);
		Show_dot(9, 29, 0x0F);
*******************************************************************************/
void Draw_Char_F6x8(u8 x, u8 y, u8 a_chChar, u8 sColor)
{
	u8 Temp, Char_Loop, Temp2;
	a_chChar = a_chChar - 32;
	u8 DotTypeGray00, DotTypeGray01, DotTypeGray10, DotTypeGray11;
//	DEBUGPRINT("\r\n a_chChar : %02x", a_chChar);
	/* Color */
	DotTypeGray00 = 0x00;
	DotTypeGray01 = (sColor & 0x0F);
	DotTypeGray10 = ((sColor << 4) & 0xF0);
//	DotTypeGray10 = (sColor << 4);
//	DotTypeGray10 = (DotTypeGray10 & 0xF0);
	DotTypeGray11 = DotTypeGray01 | DotTypeGray10;
	
	for(Char_Loop=0; Char_Loop<6; Char_Loop++){
		Temp = F6x8[a_chChar][Char_Loop];
//		DEBUGPRINT("\r\n Text : %02x", Temp);
		
		Temp2 =	(Temp & 0xC0) >> 6;
//		DEBUGPRINT("\r\n 1 : %d, %d, %02x", x, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x, y+Char_Loop, DotTypeGray11);}
		
		Temp2 =	(Temp & 0x30) >> 4;
//		DEBUGPRINT("\r\n 2 : %d, %d, %02x", x+1, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+1, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+1, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+1, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+1, y+Char_Loop, DotTypeGray11);}

		Temp2 =	(Temp & 0x0C) >> 2;
//		DEBUGPRINT("\r\n 3 : %d, %d, %02x", x+2, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+2, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+2, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+2, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+2, y+Char_Loop, DotTypeGray11);}
		
		Temp2 =	Temp & 0x03;
//		DEBUGPRINT("\r\n 4 : %d, %d, %02x", x+3, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+3, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+3, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+3, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+3, y+Char_Loop, DotTypeGray11);}
	}         
}

/*******************************************************************************
* Function Name : 
* Description   : Draw String
* Parameters    : 
* Return        : None
	Draw_Char_F9x16(10, 10, 'S', 10);
	Draw_Char_F9x16(10+5, 10, '-', 11);
	Draw_Char_F9x16(10+10, 10, 'P', 12);
	Draw_Char_F9x16(10+15, 10, 'I', 13);
	Draw_Char_F9x16(10+20, 10, 'T', 15);
*******************************************************************************/
void Draw_Char_F9x16(u8 x, u8 y, u8 a_chChar, u8 sColor)
{
	u16 Temp;
	u8 Char_Loop, Temp2;
	a_chChar = a_chChar;
	u8 DotTypeGray00, DotTypeGray01, DotTypeGray10, DotTypeGray11;
//	DEBUGPRINT("\r\n a_chChar : %02x", a_chChar);
	
	/* Color */
	DotTypeGray00 = 0x00;
	DotTypeGray01 = (sColor & 0x0F);
	DotTypeGray10 = ((sColor << 4) & 0xF0);
	DotTypeGray11 = DotTypeGray01 | DotTypeGray10;
	
	for(Char_Loop=0; Char_Loop<16; Char_Loop++){
		Temp = F9x16[a_chChar][Char_Loop];
//		DEBUGPRINT("\r\n Text : %02x", Temp);
		
		/* MSB */
		Temp2 =	(u8)((Temp & 0xC000) >> (6+8));
//		DEBUGPRINT("\r\n 1 : %d, %d, %02x", x, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x, y+Char_Loop, DotTypeGray11);}
		
		Temp2 =	(u8)((Temp & 0x3000) >> (4+8));
//		DEBUGPRINT("\r\n 2 : %d, %d, %02x", x+1, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+1, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+1, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+1, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+1, y+Char_Loop, DotTypeGray11);}

		Temp2 =	(u8)((Temp & 0x0C00) >> (2+8));
//		DEBUGPRINT("\r\n 3 : %d, %d, %02x", x+2, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+2, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+2, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+2, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+2, y+Char_Loop, DotTypeGray11);}
		
		Temp2 =	(u8)((Temp & 0x0300) >> 8);
//		DEBUGPRINT("\r\n 4 : %d, %d, %02x", x+3, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+3, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+3, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+3, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+3, y+Char_Loop, DotTypeGray11);}
		
#if 0
		/* LSB */
		Temp2 =	(u8)((Temp & 0x00C0) >> 6);
		DEBUGPRINT("\r\n 5 : %d, %d, %02x", x+4, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+4, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+4, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+4, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+4, y+Char_Loop, DotTypeGray11);}
		
		Temp2 =	(u8)((Temp & 0x0030) >> 4);
		DEBUGPRINT("\r\n 6 : %d, %d, %02x", x+5, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+5, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+5, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+5, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+5, y+Char_Loop, DotTypeGray11);}

		Temp2 =	(u8)((Temp & 0x000C) >> 2);
		DEBUGPRINT("\r\n 7 : %d, %d, %02x", x+6, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+6, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+6, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+6, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+6, y+Char_Loop, DotTypeGray11);}
		
		Temp2 =	(u8)(Temp & 0x0003);
		DEBUGPRINT("\r\n 8 : %d, %d, %02x", x+7, y+Char_Loop, Temp2);
		if(Temp2 == 0){Show_dot(x+7, y+Char_Loop, DotTypeGray00);}
		else if(Temp2 == 1){Show_dot(x+7, y+Char_Loop, DotTypeGray01);}
		else if(Temp2 == 2){Show_dot(x+7, y+Char_Loop, DotTypeGray10);}
		else if(Temp2 == 3){Show_dot(x+7, y+Char_Loop, DotTypeGray11);}		
#endif
	}
}

/*******************************************************************************
* Function Name : 
* Description   : Draw String
* Parameters    : 
* Return        : None
*******************************************************************************/
void Draw_String(u8 sMode, u8 x, u8 y, char a_chChar[], u8 sColor)
{
	u8 String_Loop;
	
	if(sMode == eFONT6_8){
		/* Vertical */
		for (String_Loop = 0; a_chChar[String_Loop] != '\0' && x+String_Loop*6<MAX_WIDTH; String_Loop++){
			Draw_Char_F6x8(x, y+String_Loop*6, a_chChar[String_Loop], sColor);
		}     
	}
	else if(sMode == eFONT9_16){
		/* Horizontal */
		for (String_Loop = 0; a_chChar[String_Loop] != '\0' && x+String_Loop*5 <MAX_WIDTH; String_Loop++){
			Draw_Char_F9x16(x+String_Loop*5, y, a_chChar[String_Loop], sColor);
		}     
	}
}

/*******************************************************************************
* Function Name : 
* Description   : Draw Char
* Parameters    : 
* Return        : None
*******************************************************************************/
void OLED_printf(u8 sMode, u8 X, u8 Y, u8 sColor, const char *fmt,...)
{
	char string[64];
	va_list ap;

	va_start(ap,fmt);
	vsprintf(string,fmt,ap);
	va_end(ap);

	Draw_String(sMode, X, Y, string, sColor);
}

/*******************************************************************************
* Function Name : 
* Description   :
* Parameters    : 
* Return        : None
*******************************************************************************/
void	Greeting_LcdMSGDock(void)
{
	char* Title = "S - Fit";
	char* Title2 = "Dock";
	char* Battery = "Batt:";

//	Draw_String(0, 5, 5, Title, 12);
//	Draw_String(0, 10, 20, Title2, 10);
//	Draw_String(0, 20, 15, Battery, 5);

//	Draw_String(1, 20, 15, Battery, 5);
	
	OLED_printf(eFONT9_16, 20, 5, 5, "%s", Title);
	OLED_printf(eFONT9_16, 20, 25, 10, "%s", Title2);
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
void OLED_INIT_SSD1362(void)
{
	/* LCD RES */
	OLED_RES(DISABLE);
	delay_ms(1); //OLED_DELAY(100);
	OLED_RES(ENABLE);
	delay_ms(1); //OLED_DELAY(100);	
		
	OLED_CMD(0xAE); //Set Display Off
	
	OLED_CMD(0x15); // Set Column Address
	OLED_CMD(0x00);
	OLED_CMD(0x4F);
	
	OLED_CMD(0x75); // Set Row Address
	OLED_CMD(0x00);
	OLED_CMD(0x3F);
	
	OLED_CMD(0x81); // Set Contrast Control
	OLED_CMD(0xB0);
	
	OLED_CMD(0xA0); // Set Re-map
	OLED_CMD(0xc1); //41
	
	OLED_CMD(0xA1); // Set Display Start Line
	OLED_CMD(0x00);
	
	OLED_CMD(0xA2); // Set Display Offset
	OLED_CMD(0x00);
	
	OLED_CMD(0xA3); // Set Vertical Scroll Area
	OLED_CMD(0x00);
	OLED_CMD(0x40);
	
	OLED_CMD(0xA4); // Set Display Mode (Normal display)
	
	OLED_CMD(0xA8); // Set MUX Ratio
	OLED_CMD(0x3F);
	
	OLED_CMD(0xAB); // Function Selection A
	OLED_CMD(0x01); // Select external VDD
	OLED_CMD(0xAD); // External /Internal IREF Selection
	OLED_CMD(0x8E); // Select external IREF
	OLED_CMD(0xB1); // Set Phase Length
	OLED_CMD(0x82);
	
	OLED_CMD(0xB3); // Set Front Clock Divider/Oscillator Frequency
	OLED_CMD(0xA0);
	
	OLED_CMD(0xB6); // Set Second precharge Period
	OLED_CMD(0x04);
	
	OLED_CMD(0xB9); // Linear LUT
	OLED_CMD(0xBC); // Set Pre-charge voltage
	OLED_CMD(0x04);
	
	OLED_CMD(0xBD); // Pre-charge voltage capacitor Selection
	OLED_CMD(0x01);
	
	OLED_CMD(0xBE); // Set VCOMH
	OLED_CMD(0x05); // 0.82*VCC
	
	/* Color 0 ~ F */
	OLED_CLEAR(0);
	
	OLED_CMD(0xAF); // Set Display ON
}

/*******************************************************************************
* Function Name : 
* Parameters    : None
* Return        : None
* Description   : 
*******************************************************************************/
void SPI_Config(u8 spi, u8 softspi)
{
  GPIO_InitTypeDef GPIO_InitStructure;
	
	if(spi == SPI_1){
			RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);

			/* LCD CS */
			GPIO_SetBits(GPIOA, GPIO_Pin_12);

			/* GPIO configuration */
			GPIO_InitStructure.GPIO_Pin = GPIO_Pin_2 | GPIO_Pin_3 | GPIO_Pin_4 | GPIO_Pin_5 | GPIO_Pin_7;
			GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
			GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
			GPIO_Init(GPIOA, &GPIO_InitStructure);		
	}
	else if(spi == SPI_2){
		
	}
	OLED_INIT_SSD1362();	
	
	
	
//	OLED_XLINE(4, 4, 3, eGRAYSCALE_1);
//	OLED_XLINE(4, 6, 4, eGRAYSCALE_2);

//	OLED_XLINE(3, 12, 3, eGRAYSCALE_3);
//	OLED_XLINE(4, 14, 5, eGRAYSCALE_4);

//	OLED_XLINE(13, 17, 9, eGRAYSCALE_15);
//	OLED_XLINE(15, 18, 25, eGRAYSCALE_14);

//	OLED_YLINE(50, 9, 25, eGRAYSCALE_15);
//	OLED_YLINE(52, 10, 26, eGRAYSCALE_12);
//	OLED_YLINE(54, 10, 25, eGRAYSCALE_11);
//	OLED_YLINE(57, 11, 24, eGRAYSCALE_13);
	
//	OLED_EN_INVERT(eINVERSEDISP);

//	delay_ms(1000);
//	OLED_EN_FADE(eFADEOUT, 0x0F);
//	delay_ms(3000);
//	OLED_EN_FADE(eFADEIN, 0x0F);

//	OLED_PIXEL(10, 10, 0x0F);
//	OLED_PIXEL(11, 10, 0x0F);
//	OLED_PIXEL(12, 10, 0x0F);

//	OLED_PIXEL(10, 15, 0x0F);
//	OLED_PIXEL(11, 16, 0x0F);



//		OLED_RECTANGLE(10, 30, 20, 20, eGRAYSCALE_15);
//		OLED_WINDOW(10, 30, 20, 20, eGRAYSCALE_15, 0x00);
		
//		Greeting_LcdMSGDock();		
}
